@@ -21,6 +21,7 @@ impl TcpHandler {
 pub(crate) async fn start_tcp_listener(
    mut listener_config: Listener,
 ) -> Result<(), Box<dyn Error>> {
+   println!("start listening on {}", &listener_config.source);
    let listener = TcpListener::bind(&listener_config.source).await?;
 
    loop {
@@ -30,7 +31,11 @@ pub(crate) async fn start_tcp_listener(
             return Ok(());
          }
       };
-      println!("new connection");
+      println!(
+         "new connection from {} forwarding to {}",
+         next_socket.peer_addr()?,
+         &listener_config.target
+      );
       let mut handler = TcpHandler {
          stream: next_socket,
          target: listener_config.target.clone(),
